.. sandman2 documentation master file, created by
   sphinx-quickstart on Fri Oct 24 08:22:11 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sandman2's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   Quickstart <quickstart>
   Interacting With Your sandman2 API <interacting>
   API <sandman2>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

